#ifndef NT2_INCLUDE_CONSTANTS__45_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS__45_HPP_INCLUDED

#include <nt2/trigonometric/include/constants/_45.hpp>

#endif
